@@ -1,15 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef SELECTCOMPONENTPAGE_H
 #define SELECTCOMPONENTPAGE_H
 
-#include <QWidget>
 #include "abstractimporter.h"
+#include <QWidget>
 
-namespace Ui {
+namespace Ui
+{
 class SelectComponentPage;
 }
 
